@@ -178,7 +178,7 @@ int btree_exists (DB *db, datum key)
 }
 
 /* initiate a sequential access */
-static inline datum btree_findkey (DB *db, u_int flags)
+static datum btree_findkey (DB *db, u_int flags)
 {
 	datum key, data;
 
@@ -192,7 +192,7 @@ static inline datum btree_findkey (DB *db, u_int flags)
 		}
 	}
 	if (!loop_check_hash)
-		loop_check_hash = hashtable_create (&plain_hashtable_free);
+		loop_check_hash = hashtable_create (&free);
 
 	if (((db->seq) (db, (DBT *) &key, (DBT *) &data, flags))) {
 		memset (&key, 0, sizeof key);
